@@ -1,5 +1,3 @@
-context("Separate")
-
 test_that("missing values in input are missing in output", {
   df <- tibble(x = c(NA, "a b"))
   out <- separate(df, x, c("x", "y"))
@@ -134,6 +132,11 @@ test_that("str_split_n handles edge cases", {
   expect_equal(str_split_n(NA, ",", 1), list(NA_character_))
 })
 
+test_that("str_split_n handles factors", {
+  expect_equal(str_split_n(factor(), ",", 1), list())
+  expect_equal(str_split_n(factor("x,x"), ",", 2), list(c("x", "x")))
+})
+
 test_that("list_indices truncates long warnings", {
   expect_equal(list_indices(letters, max = 3), "a, b, c, ...")
 })
